@@ -21,7 +21,8 @@ class History(object):
         self._headers = {
             "Authorization": "token {token}".format(token=self._token),
             "X-API-Version": "20151130",
-            "Accept": "application/json"
+            "Accept": "application/json",
+            "User-Agent": "Python API/1.1"
         }
 
         self._dataset_id = None
